

```python
for i in range(5):
    print(i)
```

```
0
1
2
3
4
```


```python
x = 12
x
```

```
12
```


```python
print("Hello Test")
```

```
Hello Test
```



Text with some inline code 2 + 2 =



